@@ -367,11 +367,30 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
                 abs_path = os.path.join(r, path)
             # END make absolute path
 
+            try:
+                st = os.lstat(abs_path)     # handles non-symlinks as well
+            except OSError:
+                # the lstat call may fail as the path may contain globs as well
+                pass
+            else:
+                if S_ISLNK(st.st_mode):
+                    yield abs_path.replace(rs, '')
+                    continue
+            # end check symlink
+
             # resolve globs if possible
             if '?' in path or '*' in path or '[' in path:
-                for f in self._iter_expand_paths(glob.glob(abs_path)):
-                    yield f.replace(rs, '')
-                continue
+                resolved_paths = glob.glob(abs_path)
+                # not abs_path in resolved_paths:
+                #   a glob() resolving to the same path we are feeding it with
+                #   is a glob() that failed to resolve. If we continued calling
+                #   ourselves we'd endlessly recurse. If the condition below
+                #   evaluates to true then we are likely dealing with a file
+                #   whose name contains wildcard characters.
+                if abs_path not in resolved_paths:
+                    for f in self._iter_expand_paths(glob.glob(abs_path)):
+                        yield f.replace(rs, '')
+                    continue
             # END glob handling
             try:
                 for root, dirs, files in os.walk(abs_path, onerror=raise_exc):
@@ -572,7 +591,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
         stream = None
         if S_ISLNK(st.st_mode):
             # in PY3, readlink is string, but we need bytes. In PY2, it's just OS encoded bytes, we assume UTF-8
-            stream = BytesIO(force_bytes(os.readlink(filepath), encoding='utf-8'))
+            stream = BytesIO(force_bytes(os.readlink(filepath), encoding=defenc))
         else:
             stream = open(filepath, 'rb')
         # END handle stream
@@ -827,7 +846,7 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
 
         :param kwargs:
             Additional keyword arguments to be passed to git-rm, such
-            as 'r' to allow recurive removal of
+            as 'r' to allow recursive removal of
 
         :return:
             List(path_string, ...) list of repository relative paths that have
@@ -911,18 +930,25 @@ class IndexFile(LazyMixin, diff.Diffable, Serializable):
 
         return out
 
-    def commit(self, message, parent_commits=None, head=True, author=None, committer=None):
+    def commit(self, message, parent_commits=None, head=True, author=None,
+               committer=None, author_date=None, commit_date=None,
+               skip_hooks=False):
         """Commit the current default index file, creating a commit object.
         For more information on the arguments, see tree.commit.
 
         :note: If you have manually altered the .entries member of this instance,
                don't forget to write() your changes to disk beforehand.
+               Passing skip_hooks=True is the equivalent of using `-n`
+               or `--no-verify` on the command line.
         :return: Commit object representing the new commit"""
-        run_commit_hook('pre-commit', self)
+        if not skip_hooks:
+            run_commit_hook('pre-commit', self)
         tree = self.write_tree()
         rval = Commit.create_from_tree(self.repo, tree, message, parent_commits,
-                                       head, author=author, committer=committer)
-        run_commit_hook('post-commit', self)
+                                       head, author=author, committer=committer,
+                                       author_date=author_date, commit_date=commit_date)
+        if not skip_hooks:
+            run_commit_hook('post-commit', self)
         return rval
 
     @classmethod
